==> Qt-Gui-0.01_02.tar.gz: Qt-Gui-0.01_02/lib/Qt/Gui/QTextBlockFormat.pm <==
package Qt::Gui::QTextBlockFormat;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QTextBlockFormat
# file     : QtGui/qtextformat.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Gui::QTextFormat/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QTextBlockFormat

=head1 PUBLIC METHODS

=over

=item   QTextBlockFormat()

=item  QFlags<Qt::AlignmentFlag> alignment()

=item  qreal bottomMargin()

=item  int indent()

=item  bool isValid()

=item  qreal leftMargin()

=item  bool nonBreakableLines()

=item  QFlags<QTextFormat::PageBreakFlag> pageBreakPolicy()

=item  qreal rightMargin()

=item  void setAlignment(QFlags<Qt::AlignmentFlag> alignment)

=item  void setBottomMargin(qreal margin)

=item  void setIndent(int indent)

=item  void setLeftMargin(qreal margin)

=item  void setNonBreakableLines(bool b)

=item  void setPageBreakPolicy(QFlags<QTextFormat::PageBreakFlag> flags)

=item  void setRightMargin(qreal margin)

=item  void setTextIndent(qreal aindent)

=item  void setTopMargin(qreal margin)

=item  qreal textIndent()

=item  qreal topMargin()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut

==> Qt-Gui-0.01_05.tar.gz: Qt-Gui-0.01_05/lib/Qt/Gui/QTextBlockFormat.pm <==
package Qt::Gui::QTextBlockFormat;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QTextBlockFormat
# file     : QtGui/qtextformat.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_05';
use base qw/Qt::Gui::QTextFormat/;
#our @ISA = qw/Qt::Gui::QTextFormat/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QTextBlockFormat

=head1 PUBLIC METHODS

=over

=item   QTextBlockFormat()

=item  QFlags<Qt::AlignmentFlag> alignment()

=item  qreal bottomMargin()

=item  int indent()

=item  bool isValid()

=item  qreal leftMargin()

=item  bool nonBreakableLines()

=item  QFlags<QTextFormat::PageBreakFlag> pageBreakPolicy()

=item  qreal rightMargin()

=item  void setAlignment(QFlags<Qt::AlignmentFlag> alignment)

=item  void setBottomMargin(qreal margin)

=item  void setIndent(int indent)

=item  void setLeftMargin(qreal margin)

=item  void setNonBreakableLines(bool b)

=item  void setPageBreakPolicy(QFlags<QTextFormat::PageBreakFlag> flags)

=item  void setRightMargin(qreal margin)

=item  void setTabPositions(const QList<QTextOption::Tab> & tabs)

=item  void setTextIndent(qreal aindent)

=item  void setTopMargin(qreal margin)

=item  QList<QTextOption::Tab> tabPositions()

=item  qreal textIndent()

=item  qreal topMargin()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2012 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
